@@ -65,6 +65,7 @@ class Flask(ShortCuts, flask.Flask):
         _config_from_object = self.config.from_object
 
         def config_from_object(*args, **kwargs):
+            self.config['DEBUG'] = 'DEBUG' in environ
             _config_from_object(*args, **kwargs)
             self.config['SQLALCHEMY_ECHO'] = 'SQLALCHEMY_ECHO' in environ
             self.config['DEBUG_TB_INTERCEPT_REDIRECTS'] = \
@@ -199,7 +200,7 @@ def timestamp(dt):
     return int(dt.strftime("%s"))
 
 
-class ShortHandMixin(object):
+class ExistsMixin(object):
     @classmethod
     def exists(cls, clause):
         if not isinstance(clause, ClauseElement):
@@ -224,7 +225,7 @@ class TimesMixin(object):
     )
 
 
-class AllMixin(PKMixin, TimesMixin, ShortHandMixin):
+class AllMixin(PKMixin, TimesMixin, ExistsMixin):
     pass
 
 
